##  Capturing Systems with SAP Discovery
An SAP system refers to the full technical environment supporting ERP solutions and related business applications, including the application server, database, and system-specific configurations. The SAP discovery feature automatically discovers SAP systems and services and captures the following:
  * SAP system ID and SAP system number. For example: "P2W" and "3728388424". Both will also appear on the fact sheet name by default.
  * SAP deployment model. For example: SAP Public Cloud, SAP Private Cloud, or SAP On-Premise
  * SAP environment in which the system is running. For example: Development, quality assurance, or production.
  * Installation number and customer number.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0177ba9d4414450bb3255dd90593eb7c_LowRes.png)
SAP System-Specific Attributes
During the discovery process, the associated applications and IT components are also discovered and automatically linked to the reference catalog. For a detailed guide, see [SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Identify and manage your organization's SAP systems, services, and custom-built extensions"). Capturing this information enables better tracking, analysis, and decision-making. For example, using the application landscape report clustered by systems, you can see which applications run on which SAP systems. You can also generate aggregated reports based on deployment environments or deployment models, to categorize and analyze applications and IT components based on deployment models, such as cloud versus on-premise. For a more detailed guide on SAP system modeling, see [Modeling SAP Systems](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b51c67a441014ac6decfb689f86ca__section_gcv_ljm_sfc).
Modeling Examples:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiofa502f200e2942d69188c75ef890582a_HiRes.png)![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio310cfd784d564fd29ebe2fa44a96792b_HiRes.png)
